@@ -25,7 +25,8 @@ sub match {
         |destination[ ]server[ ]rejected[ ]recipients
         |email[ ]address[ ]does[ ]not[ ]exist
         |invalid[ ](?:
-             mailbox[ ]path
+             address
+            |mailbox[ ]path
             |recipient                 # Linkedin
             )
         |is[ ]not[ ](?:
@@ -128,11 +129,11 @@ sub true {
     return 1 if $argvs->reason eq __PACKAGE__->text;
 
     require Sisimai::SMTP::Status;
-    my $prematches = [ 'NoRelaying', 'Blocked', 'MailboxFull', 'HasMoved' ];
+    my $prematches = ['NoRelaying', 'Blocked', 'MailboxFull', 'HasMoved'];
     my $matchother = 0;
     my $statuscode = $argvs->deliverystatus // '';
     my $diagnostic = $argvs->diagnosticcode // '';
-    my $tempreason = Sisimai::SMTP::Status->name( $statuscode );
+    my $tempreason = Sisimai::SMTP::Status->name($statuscode);
     my $reasontext = __PACKAGE__->text;
     my $v = 0;
 
@@ -147,9 +148,9 @@ sub true {
         for my $e ( @$prematches ) {
             # Check the value of "Diagnostic-Code" with other error patterns.
             my $p = 'Sisimai::Reason::'.$e;
-            Module::Load::load( $p );
+            Module::Load::load($p);
 
-            if( $p->match( $diagnostic ) ) {
+            if( $p->match($diagnostic) ) {
                 # Match with reason defined in Sisimai::Reason::* Except 
                 # UserUnknown.
                 $matchother = 1;
@@ -165,7 +166,7 @@ sub true {
         if( $argvs->smtpcommand eq 'RCPT' ) {
             # When the SMTP command is not "RCPT", the session rejected by other
             # reason, maybe.
-            $v = 1 if __PACKAGE__->match( $diagnostic );
+            $v = 1 if __PACKAGE__->match($diagnostic);
         }
     }
 
@@ -210,13 +211,13 @@ C<text()> returns string: C<userunknown>.
 
     print Sisimai::Reason::UserUnknown->text;  # userunknown
 
-=head2 C<B<match( I<string> )>>
+=head2 C<B<match(I<string>)>>
 
 C<match()> returns 1 if the argument matched with patterns defined in this class.
 
     print Sisimai::Reason::UserUnknown->match('550 5.1.1 Unknown User');   # 1
 
-=head2 C<B<true( I<Sisimai::Data> )>>
+=head2 C<B<true(I<Sisimai::Data>)>>
 
 C<true()> returns 1 if the bounce reason is C<userunknown>. The argument must be
 Sisimai::Data object and this method is called only from Sisimai::Reason class.
